# -*- coding: utf-8 -*-

"""
该模块用于实现 DB App 的具体业务逻辑.

**开发者说明**

本模块下的所有具体业务逻辑都会被封装成函数. 每个函数必定带有一个 :class:`~acore_db_app.orm.Orm`
的输入参数. 这个参数绑定了数据库连接以及所有的数据表定义. 换言之, 我们的底层函数实现并不关心具体
跟哪个数据库建立连接. 因为底层函数是被作为类库来设计的, 最终的用户自己需要决定跟哪个数据库建立连接.
"""
